UdAlertWidget class

Inheritance

Constructors

UdAlertWidget({String? title, double? titleFontSize, String? message, double? messageFontSize, String? button1Text, double? button1FontSize, Function? button1Function, String? button2Text, double? button2FontSize, Function? button2Function, double? alertBorderRadius, Color? colorAroundTheAlert, bool? closeAlertOnTapArround})
To show some information in an alert you can use this widget. It should be used where the return type is Widget

Properties

alertBorderRadius → double?
final
button1FontSize → double?
final
button1Function → Function?
final
button1Text → String?
final
button2FontSize → double?
final
button2Function → Function?
final
button2Text → String?
final
closeAlertOnTapArround → bool?
final
colorAroundTheAlert → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message → String?
final
messageFontSize → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
titleFontSize → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited