UdAppBar class

Inheritance
Implemented types

Constructors

UdAppBar({required BuildContext context, double? height, Color? backgroundColor, String? titleText, Color? titleColor, double? titleFontSize, FontWeight? titleFontWeight, Alignment? titleAlignment, double? titleWidth, double? titlePaddingLeft, double? titlePaddingRight, Widget? customDesign, Widget? customLeft, Widget? customMiddle, Widget? customRight, double? appBarPaddingLeft, double? appBarPaddingright, bool? disableShadow, double? shadowBlurRadius, Color? shadowColor, Offset? shadowOffset, double? shadowSpreadRadius, bool? gradientEnable, LinearGradient? gradient})
UdAppBar is a simplified and responsive appbar and very easy to use. We provided possible options for you so that you can customize it easily.

Properties

appBarPaddingLeft → double?
final
appBarPaddingright → double?
final
backgroundColor → Color?
final
context → BuildContext
final
customDesign → Widget?
If you want full customization over this appbar widget then use this paramenter.
final
customLeft → Widget?
If you want any customization or widget in the left side then use this parameter.
final
customMiddle → Widget?
If you want any customization or widget in the middle then use this parameter.
final
customRight → Widget?
If you want any customization or widget in the right side then use this parameter.
final
disableShadow → bool?
By default this AppBar has a shadow. If you do not need shadow then you can pass false here to disable shadow.
final
gradient → LinearGradient?
Here you can pass your Gradient widget to show gradient color as background of AppBar.
final
gradientEnable → bool?
If you want the background color of the appbar to be gradient then you have to enable it by passing true here. After that you can pass any Gradient widget.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
preferredSize → Size
The size this widget would prefer if it were otherwise unconstrained.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowBlurRadius → double?
final
shadowColor → Color?
final
shadowOffset → Offset?
final
shadowSpreadRadius → double?
final
titleAlignment → Alignment?
final
titleColor → Color?
final
titleFontSize → double?
final
titleFontWeight → FontWeight?
final
titlePaddingLeft → double?
final
titlePaddingRight → double?
final
titleText → String?
If you do not need any custom widget and just need a title then you can use this parameter.
final
titleWidth → double?
final

Methods

build(BuildContext contextInside) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited