UdBasicButton class

Inheritance

Constructors

UdBasicButton({double? width, double? height, Color? backgroundColor, String? title, double? titleFontSize, Color? titleColor, FontWeight? titleFontWeight, double? paddingArroundTitle, Color? borderColor, Color? foregroundColor, Color? surfaceTintColor, double? borderWidth, double? borderRadius, BorderRadius? customBorderRadius, Color? shadowColor, Offset? shadowOffset, double? shadowBlurRadius, double? shadowSpreadRadius, Color? splashColor, bool? disableShadow, bool? skipTraversal, Widget? customChild, Function? onTap})
UdBasicButton is a basic button made with possible options that a developer will need. Modify the button in your way passing values.

Properties

backgroundColor → Color?
final
borderColor → Color?
final
borderRadius → double?
final
borderWidth → double?
final
customBorderRadius → BorderRadius?
final
customChild → Widget?
final
disableShadow → bool?
final
foregroundColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → Function?
final
paddingArroundTitle → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowBlurRadius → double?
final
shadowColor → Color?
final
shadowOffset → Offset?
final
shadowSpreadRadius → double?
final
skipTraversal → bool?
final
splashColor → Color?
final
surfaceTintColor → Color?
final
title → String?
final
titleColor → Color?
final
titleFontSize → double?
final
titleFontWeight → FontWeight?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited