UdRadioButton class

Inheritance

Constructors

UdRadioButton({double? size, double? innerMargin, double? borderRadius, String? title, double? titleFontSize, Color? titleColor, FontWeight? titleWeight, MainAxisAlignment? mainAxisAlignment, bool? checked, dynamic value, int? index, ValueChanged? onTap, ValueChanged<int?>? getIndex, bool? skipTraversal})
You can modify this radio button passing values by your choice.

Properties

borderRadius → double?
final
checked → bool?
To check on the radio button pass true or false here.
final
getIndex → ValueChanged<int?>?
Called when the user taps on the radio button and it returns the index value you passed in the widget.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int?
Pass index number if you need it on tap using getIndex function
final
innerMargin → double?
It makes space inside when button is checked
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment → MainAxisAlignment?
final
onTap → ValueChanged?
Called when the user taps on the radio button and it returns the value you passed in the widget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
final
skipTraversal → bool?
final
title → String?
final
titleColor → Color?
final
titleFontSize → double?
final
titleWeight → FontWeight?
final
value → dynamic
Pass a value to get it on tap and match for checking the radio button.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited