UdCard class

Inheritance

Constructors

UdCard({double? width, double? height, Color? backgroundColor, double? paddingHorizontal, double? paddingVertical, Color? borderColor, double? borderWidth, double? borderRadius, BorderRadius? customBorderRadius, bool? disableShadow, Color? shadowColor, Offset? shadowOffset, double? shadowBlurRadius, double? shadowSpreadRadius, bool? gradientEnable, Gradient? gradient, Widget? child})
UdCard is simplified and very easy to use when you need a card design. We provided possible parameters for you so that you can design it on your way.

Properties

backgroundColor → Color?
final
borderColor → Color?
To show border you must provide borderColor.
final
borderRadius → double?
final
borderWidth → double?
To show border you must provide borderColor.
final
child → Widget?
final
customBorderRadius → BorderRadius?
final
disableShadow → bool?
By default this UdCard has a shadow. If you do not need shadow then you can pass false here to disable shadow.
final
gradient → Gradient?
Here you can pass your Gradient widget to show gradient color as background of UdCard.
final
gradientEnable → bool?
If you want the background color of the card to be gradient then you have to enable it by passing true here. After that you can pass any Gradient widget.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
paddingHorizontal → double?
final
paddingVertical → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowBlurRadius → double?
final
shadowColor → Color?
final
shadowOffset → Offset?
final
shadowSpreadRadius → double?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited