UdBasicTextInputField class

Inheritance

Constructors

UdBasicTextInputField({double? height, double? width, int? index, String? hintText, Color? hintTextColor, Color? textColor, double? fontSize, FontWeight? fontWeight, TextAlign? textAlignment, bool? obsecureText, bool? readOnly, Color? backgroundColor, Color? borderColor, double? borderWidth, double? borderRadius, EdgeInsets? padding, bool? disableShadow, Color? shadowColor, Offset? shadowOffset, double? shadowBlurRadius, double? shadowSpreadRadius, Widget? leftItem, ValueChanged? onChanged, Function? onTap, Function? onEditingComplete, ValueChanged<int>? getIndex, TextEditingController? controller, FocusNode? focusNode, List<TextInputFormatter>? textInputFormatters, TextInputType? textInputType, TextInputAction? textInputAction})

Properties

backgroundColor → Color?
final
borderColor → Color?
final
borderRadius → double?
final
borderWidth → double?
final
controller → TextEditingController?
final
disableShadow → bool?
final
focusNode → FocusNode?
final
fontSize → double?
final
fontWeight → FontWeight?
final
getIndex → ValueChanged<int>?
Called when the user taps on the text input field and it returns the index value you passed in the widget.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
hintText → String?
final
hintTextColor → Color?
final
index → int?
Pass index number if you need it on tap using getIndex function
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftItem → Widget?
final
obsecureText → bool?
final
onChanged → ValueChanged?
Use this parameter to listen for the changes on every key press.
final
onEditingComplete → Function?
final
onTap → Function?
final
padding → EdgeInsets?
final
readOnly → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowBlurRadius → double?
final
shadowColor → Color?
final
shadowOffset → Offset?
final
shadowSpreadRadius → double?
final
textAlignment → TextAlign?
final
textColor → Color?
final
textInputAction → TextInputAction?
final
textInputFormatters → List<TextInputFormatter>?
final
textInputType → TextInputType?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited